# Generated by Django 5.2.10 on 2026-03-06 14:37

import django.db.models.deletion
import django_resaas.models.documento
import django_resaas.models.entidade
import django_resaas.models.tipo_entidade
import django_resaas.models.user
import uuid
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('auth', '0012_alter_user_first_name_max_length'),
        ('contenttypes', '0002_remove_content_type_name'),
    ]

    operations = [
        migrations.CreateModel(
            name='FrontEnd',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('nome', models.CharField(max_length=100)),
                ('fek', models.CharField(max_length=255, unique=True)),
                ('fep', models.CharField(max_length=255)),
                ('access', models.CharField(choices=[('read', 'Read'), ('write', 'Write'), ('readwrite', 'Read & Write'), ('super', 'Super')], default='read', max_length=20)),
                ('estado', models.IntegerField(choices=[(0, 'Inativo'), (1, 'Ativo')], default=1)),
            ],
            options={
                'permissions': (),
            },
        ),
        migrations.CreateModel(
            name='TipoDocumento',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('nome', models.CharField(max_length=200)),
                ('detalhes', models.CharField(max_length=200)),
            ],
        ),
        migrations.CreateModel(
            name='User',
            fields=[
                ('deleted_at', models.DateTimeField(blank=True, null=True)),
                ('estado', models.IntegerField(choices=[(0, 'Inativo'), (1, 'Ativo')], default=0, null=True)),
                ('password', models.CharField(max_length=128, verbose_name='password')),
                ('last_login', models.DateTimeField(blank=True, null=True, verbose_name='last login')),
                ('is_superuser', models.BooleanField(default=False, help_text='Designates that this user has all permissions without explicitly assigning them.', verbose_name='superuser status')),
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('perfil', models.ImageField(blank=True, default='user.png', null=True, upload_to=django_resaas.models.user.profile_image_path)),
                ('username', models.CharField(max_length=255)),
                ('first_name', models.CharField(blank=True, max_length=255, null=True)),
                ('last_name', models.CharField(blank=True, max_length=255, null=True)),
                ('mobile', models.CharField(blank=True, default=None, max_length=55, null=True, unique=True)),
                ('is_verified_mobile', models.BooleanField(default=False)),
                ('counter', models.IntegerField(default=0)),
                ('email', models.EmailField(blank=True, default=None, max_length=255, null=True, unique=True)),
                ('is_verified_email', models.BooleanField(default=False)),
                ('is_active', models.BooleanField(default=True)),
                ('is_staff', models.BooleanField(default=False)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('auth_provider', models.CharField(choices=[('email', 'email'), ('facebook', 'facebook'), ('google', 'google'), ('twitter', 'twitter'), ('mobile', 'maobile')], default='email', max_length=255)),
                ('created_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_created', to=settings.AUTH_USER_MODEL)),
                ('groups', models.ManyToManyField(blank=True, help_text='The groups this user belongs to. A user will get all permissions granted to each of their groups.', related_name='user_set', related_query_name='user', to='auth.group', verbose_name='groups')),
                ('updated_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_updated', to=settings.AUTH_USER_MODEL)),
                ('user_permissions', models.ManyToManyField(blank=True, help_text='Specific permissions for this user.', related_name='user_set', related_query_name='user', to='auth.permission', verbose_name='user permissions')),
            ],
            options={
                'verbose_name': 'User',
                'verbose_name_plural': 'Users',
                'permissions': (),
            },
        ),
        migrations.CreateModel(
            name='Endereco',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('deleted_at', models.DateTimeField(blank=True, null=True)),
                ('estado', models.IntegerField(choices=[(0, 'Inativo'), (1, 'Ativo')], default=0, null=True)),
                ('latitude', models.DecimalField(blank=True, decimal_places=6, max_digits=9, null=True)),
                ('longitude', models.DecimalField(blank=True, decimal_places=6, max_digits=9, null=True)),
                ('rua', models.CharField(blank=True, max_length=255, null=True)),
                ('numero', models.CharField(blank=True, max_length=50, null=True)),
                ('bairro', models.CharField(blank=True, max_length=100, null=True)),
                ('cidade', models.CharField(blank=True, max_length=100, null=True)),
                ('provincia', models.CharField(blank=True, max_length=100, null=True)),
                ('pais', models.CharField(default='Moçambique', max_length=100)),
                ('codigo_postal', models.CharField(blank=True, max_length=20, null=True)),
                ('complemento', models.TextField(blank=True, null=True)),
                ('created_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_created', to=settings.AUTH_USER_MODEL)),
                ('updated_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_updated', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'Endereço',
                'verbose_name_plural': 'Endereços',
                'permissions': (),
            },
        ),
        migrations.CreateModel(
            name='Entidade',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('deleted_at', models.DateTimeField(blank=True, null=True)),
                ('estado', models.IntegerField(choices=[(0, 'Inativo'), (1, 'Ativo')], default=0, null=True)),
                ('nome', models.CharField(default='-', max_length=100, null=True)),
                ('logo', models.FileField(blank=True, default='logo.png', upload_to=django_resaas.models.entidade.logo_path)),
                ('display_logo', models.BooleanField(blank=True, default=True, null=True)),
                ('display_bar', models.BooleanField(blank=True, default=True, null=True)),
                ('display_qr', models.BooleanField(blank=True, default=True, null=True)),
                ('rodape', models.CharField(max_length=2000, null=True)),
                ('disc_space', models.FloatField(default=1048576.0, null=True)),
                ('disc_used_space', models.FloatField(default=0.0, null=True)),
                ('disc_free_space', models.FloatField(default=1048576.0, null=True)),
                ('admins', models.ManyToManyField(to=settings.AUTH_USER_MODEL)),
                ('created_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_created', to=settings.AUTH_USER_MODEL)),
                ('updated_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_updated', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'permissions': (),
            },
        ),
        migrations.CreateModel(
            name='EntidadeModelo',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('deleted_at', models.DateTimeField(blank=True, null=True)),
                ('estado', models.IntegerField(choices=[(0, 'Inativo'), (1, 'Ativo')], default=0, null=True)),
                ('created_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_created', to=settings.AUTH_USER_MODEL)),
                ('entidade', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_resaas.entidade')),
                ('modelo', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='contenttypes.contenttype')),
                ('updated_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_updated', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'permissions': (),
            },
        ),
        migrations.CreateModel(
            name='EntidadeUser',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('deleted_at', models.DateTimeField(blank=True, null=True)),
                ('estado', models.IntegerField(choices=[(0, 'Inativo'), (1, 'Ativo')], default=0, null=True)),
                ('created_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_created', to=settings.AUTH_USER_MODEL)),
                ('entidade', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_resaas.entidade')),
                ('updated_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_updated', to=settings.AUTH_USER_MODEL)),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'permissions': (),
            },
        ),
        migrations.CreateModel(
            name='Ficheiro',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('deleted_at', models.DateTimeField(blank=True, null=True)),
                ('ficheiro', models.FileField(blank=True, null=True, upload_to='ficheiros')),
                ('size', models.FloatField()),
                ('modelo', models.CharField(help_text='Nome do modelo que originou o ficheiro', max_length=100, null=True)),
                ('estado', models.IntegerField(choices=[(0, 'Inactivo'), (1, 'Activo')], default=1, null=True)),
                ('funcionalidade', models.CharField(choices=[('File', 'File'), ('Perfil', 'Perfil'), ('Logo', 'Logo'), ('Foto', 'Foto'), ('CapaSite', 'CapaSite')], default='File', max_length=100, null=True)),
                ('chamador', models.CharField(blank=True, max_length=100, null=True)),
                ('created_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_created', to=settings.AUTH_USER_MODEL)),
                ('updated_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_updated', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'permissions': (),
            },
        ),
        migrations.CreateModel(
            name='Idioma',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('deleted_at', models.DateTimeField(blank=True, null=True)),
                ('estado', models.IntegerField(choices=[(0, 'Inativo'), (1, 'Ativo')], default=0, null=True)),
                ('nome', models.CharField(max_length=100)),
                ('code', models.CharField(max_length=10, unique=True)),
                ('created_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_created', to=settings.AUTH_USER_MODEL)),
                ('updated_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_updated', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'permissions': (),
            },
        ),
        migrations.AddField(
            model_name='user',
            name='language',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='django_resaas.idioma'),
        ),
        migrations.CreateModel(
            name='ModeloExtra',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('deleted_at', models.DateTimeField(blank=True, null=True)),
                ('estado', models.IntegerField(choices=[(0, 'Inativo'), (1, 'Ativo')], default=0, null=True)),
                ('modelo', models.CharField(max_length=100, null=True)),
                ('icon', models.CharField(max_length=100, null=True)),
                ('method', models.CharField(max_length=50, null=True)),
                ('permission', models.CharField(max_length=100, null=True)),
                ('details', models.BooleanField(default=False)),
                ('url', models.CharField(max_length=300, null=True)),
                ('created_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_created', to=settings.AUTH_USER_MODEL)),
                ('updated_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_updated', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'permissions': (),
            },
        ),
        migrations.CreateModel(
            name='Modulo',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('deleted_at', models.DateTimeField(blank=True, null=True)),
                ('estado', models.IntegerField(choices=[(0, 'Inativo'), (1, 'Ativo')], default=0, null=True)),
                ('nome', models.CharField(max_length=100, null=True)),
                ('created_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_created', to=settings.AUTH_USER_MODEL)),
                ('updated_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_updated', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'permissions': (),
            },
        ),
        migrations.CreateModel(
            name='EntidadeModulo',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('deleted_at', models.DateTimeField(blank=True, null=True)),
                ('estado', models.IntegerField(choices=[(0, 'Inativo'), (1, 'Ativo')], default=0, null=True)),
                ('created_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_created', to=settings.AUTH_USER_MODEL)),
                ('entidade', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_resaas.entidade')),
                ('updated_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_updated', to=settings.AUTH_USER_MODEL)),
                ('modulo', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_resaas.modulo')),
            ],
            options={
                'permissions': (),
            },
        ),
        migrations.CreateModel(
            name='Sucursal',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('deleted_at', models.DateTimeField(blank=True, null=True)),
                ('estado', models.IntegerField(choices=[(0, 'Inativo'), (1, 'Ativo')], default=0, null=True)),
                ('nome', models.CharField(max_length=100, null=True)),
                ('rodape', models.CharField(default='.', max_length=600, null=True)),
                ('icon', models.CharField(default='.', max_length=100, null=True)),
                ('label', models.CharField(default='.', max_length=100, null=True)),
                ('created_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_created', to=settings.AUTH_USER_MODEL)),
                ('endereco', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='django_resaas.endereco')),
                ('entidade', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_resaas.entidade')),
                ('updated_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_updated', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'permissions': (),
            },
        ),
        migrations.CreateModel(
            name='SucursalUser',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('deleted_at', models.DateTimeField(blank=True, null=True)),
                ('estado', models.IntegerField(choices=[(0, 'Inativo'), (1, 'Ativo')], default=0, null=True)),
                ('created_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_created', to=settings.AUTH_USER_MODEL)),
                ('sucursal', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_resaas.sucursal')),
                ('updated_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_updated', to=settings.AUTH_USER_MODEL)),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'permissions': (),
            },
        ),
        migrations.CreateModel(
            name='SucursalUserGroup',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('deleted_at', models.DateTimeField(blank=True, null=True)),
                ('estado', models.IntegerField(choices=[(0, 'Inativo'), (1, 'Ativo')], default=0, null=True)),
                ('created_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_created', to=settings.AUTH_USER_MODEL)),
                ('group', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='auth.group')),
                ('sucursal', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_resaas.sucursal')),
                ('updated_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_updated', to=settings.AUTH_USER_MODEL)),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'permissions': (),
            },
        ),
        migrations.CreateModel(
            name='TipoEntidade',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('deleted_at', models.DateTimeField(blank=True, null=True)),
                ('estado', models.IntegerField(choices=[(0, 'Inativo'), (1, 'Ativo')], default=0, null=True)),
                ('nome', models.CharField(max_length=100, null=True)),
                ('icon', models.FileField(blank=True, default='logo.png', upload_to=django_resaas.models.tipo_entidade.icon_path)),
                ('license', models.TextField(default='license')),
                ('label', models.CharField(max_length=100, null=True)),
                ('ordem', models.IntegerField(default=2)),
                ('crair_entidade', models.BooleanField(default=True, null=True)),
                ('created_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_created', to=settings.AUTH_USER_MODEL)),
                ('updated_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_updated', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'permissions': (),
            },
        ),
        migrations.AddField(
            model_name='entidade',
            name='tipo_entidade',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_resaas.tipoentidade'),
        ),
        migrations.CreateModel(
            name='TipoEntidadeGroup',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('deleted_at', models.DateTimeField(blank=True, null=True)),
                ('estado', models.IntegerField(choices=[(0, 'Inativo'), (1, 'Ativo')], default=0, null=True)),
                ('created_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_created', to=settings.AUTH_USER_MODEL)),
                ('group', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='auth.group')),
                ('tipo_entidade', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_resaas.tipoentidade')),
                ('updated_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_updated', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'permissions': (),
            },
        ),
        migrations.CreateModel(
            name='TipoEntidadeModelo',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('deleted_at', models.DateTimeField(blank=True, null=True)),
                ('estado', models.IntegerField(choices=[(0, 'Inativo'), (1, 'Ativo')], default=0, null=True)),
                ('created_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_created', to=settings.AUTH_USER_MODEL)),
                ('modelo', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='contenttypes.contenttype')),
                ('tipo_entidade', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_resaas.tipoentidade')),
                ('updated_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_updated', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'permissions': (),
            },
        ),
        migrations.CreateModel(
            name='TipoEntidadeModulo',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('deleted_at', models.DateTimeField(blank=True, null=True)),
                ('estado', models.IntegerField(choices=[(0, 'Inativo'), (1, 'Ativo')], default=0, null=True)),
                ('created_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_created', to=settings.AUTH_USER_MODEL)),
                ('modulo', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_resaas.modulo')),
                ('tipo_entidade', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_resaas.tipoentidade')),
                ('updated_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_updated', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'permissions': (),
            },
        ),
        migrations.CreateModel(
            name='Traducao',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('deleted_at', models.DateTimeField(blank=True, null=True)),
                ('estado', models.IntegerField(choices=[(0, 'Inativo'), (1, 'Ativo')], default=0, null=True)),
                ('chave', models.TextField(blank=True, null=True)),
                ('traducao', models.TextField(blank=True, null=True)),
                ('created_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_created', to=settings.AUTH_USER_MODEL)),
                ('idioma', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_resaas.idioma')),
                ('updated_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_updated', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'permissions': (),
            },
        ),
        migrations.CreateModel(
            name='UserLogin',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('deleted_at', models.DateTimeField(blank=True, null=True)),
                ('estado', models.IntegerField(choices=[(0, 'Inativo'), (1, 'Ativo')], default=0, null=True)),
                ('dispositivo', models.TextField(null=True)),
                ('mobile', models.CharField(max_length=100, null=True)),
                ('info', models.TextField(null=True)),
                ('local_lat', models.CharField(max_length=100, null=True)),
                ('local_lon', models.CharField(max_length=100, null=True)),
                ('local_nome', models.CharField(max_length=100, null=True)),
                ('is_blocked', models.BooleanField(default=False)),
                ('created_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_created', to=settings.AUTH_USER_MODEL)),
                ('updated_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_updated', to=settings.AUTH_USER_MODEL)),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'permissions': (),
            },
        ),
        migrations.CreateModel(
            name='EntidadeGroup',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('deleted_at', models.DateTimeField(blank=True, null=True)),
                ('estado', models.IntegerField(choices=[(0, 'Inativo'), (1, 'Ativo')], default=0, null=True)),
                ('created_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_created', to=settings.AUTH_USER_MODEL)),
                ('entidade', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_resaas.entidade')),
                ('group', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='auth.group')),
                ('updated_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_updated', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'permissions': (),
                'unique_together': {('entidade', 'group')},
            },
        ),
        migrations.CreateModel(
            name='Pessoa',
            fields=[
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('deleted_at', models.DateTimeField(blank=True, null=True)),
                ('estado', models.IntegerField(choices=[(0, 'Inativo'), (1, 'Ativo')], default=0, null=True)),
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('nome', models.CharField(max_length=100, null=True)),
                ('apelido', models.CharField(max_length=100, null=True)),
                ('nome_completo', models.CharField(blank=True, max_length=200, null=True)),
                ('genero', models.CharField(blank=True, choices=[('M', 'Masculino'), ('F', 'Feminino'), ('O', 'Outro')], max_length=1, null=True)),
                ('data_nascimento', models.DateField(blank=True, null=True)),
                ('nacionalidade', models.CharField(blank=True, max_length=100, null=True)),
                ('email', models.EmailField(blank=True, max_length=254, null=True, unique=True)),
                ('telefone', models.CharField(blank=True, max_length=20, null=True)),
                ('telefone_alternativo', models.CharField(blank=True, max_length=20, null=True)),
                ('observacoes', models.TextField(blank=True, null=True)),
                ('created_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_created', to=settings.AUTH_USER_MODEL)),
                ('endereco', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='pessoas', to='django_resaas.endereco')),
                ('updated_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_updated', to=settings.AUTH_USER_MODEL)),
                ('user', models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='pessoa', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'Pessoa',
                'verbose_name_plural': 'Pessoas',
                'ordering': ['nome'],
                'indexes': [models.Index(fields=['nome'], name='django_resa_nome_75d7c2_idx'), models.Index(fields=['email'], name='django_resa_email_47cf4d_idx')],
            },
        ),
        migrations.CreateModel(
            name='SucursalGroup',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('deleted_at', models.DateTimeField(blank=True, null=True)),
                ('estado', models.IntegerField(choices=[(0, 'Inativo'), (1, 'Ativo')], default=0, null=True)),
                ('created_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_created', to=settings.AUTH_USER_MODEL)),
                ('group', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='auth.group')),
                ('sucursal', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_resaas.sucursal')),
                ('updated_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_updated', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'permissions': (),
                'unique_together': {('sucursal', 'group')},
            },
        ),
        migrations.CreateModel(
            name='Documento',
            fields=[
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('deleted_at', models.DateTimeField(blank=True, null=True)),
                ('estado', models.IntegerField(choices=[(0, 'Inativo'), (1, 'Ativo')], default=0, null=True)),
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('numero', models.CharField(max_length=100)),
                ('data_emissao', models.DateField(blank=True, null=True)),
                ('data_validade', models.DateField(blank=True, null=True)),
                ('arquivo', models.FileField(blank=True, null=True, upload_to=django_resaas.models.documento.documento_path)),
                ('object_id', models.UUIDField()),
                ('content_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='contenttypes.contenttype')),
                ('created_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_created', to=settings.AUTH_USER_MODEL)),
                ('updated_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_updated', to=settings.AUTH_USER_MODEL)),
                ('tipo', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_resaas.tipodocumento')),
            ],
            options={
                'unique_together': {('tipo', 'numero')},
            },
        ),
    ]



import importlib

from django.apps import apps
from django_resaas.models.idioma import Idioma
from django_resaas.models.traducao import Traducao


class TraducaoSyncService:
    """
    Sincroniza traduções a partir de módulos app.lang.<idioma>
    para a base de dados.
    """

    @classmethod
    def sync(cls, stdout=None, style=None):
        idiomas = Idioma.objects.all()

        for idioma in idiomas:
            lang_code = idioma.code.lower().replace("-", "")

            if stdout:
                stdout.write(
                    style.MIGRATE_HEADING(
                        f"\n🌍 Sincronizando idioma: {idioma.nome} ({lang_code})"
                    )
                )

            for app in apps.get_app_configs():
                module_name = f"{app.name}.lang.{lang_code}"

                try:
                    module = importlib.import_module(module_name)
                except ModuleNotFoundError:
                    continue

                if not hasattr(module, "key_value"):
                    continue

                cls._sync_module(
                    idioma,
                    module.key_value,
                    app.label,
                    stdout,
                    style
                )

    @staticmethod
    def _sync_module(idioma, traducoes, app_label, stdout=None, style=None):
        for chave, traducao in traducoes.items():
            obj, created = Traducao.objects.get_or_create(
                idioma=idioma,
                chave=chave,
                defaults={"traducao": traducao}
            )

            if not created and obj.traducao != traducao:
                obj.traducao = traducao
                obj.save(update_fields=["traducao"])

                if stdout:
                    stdout.write(
                        style.SUCCESS(
                            f"🔁 Atualizada [{app_label}]: {chave}"
                        )
                    )
            elif created:
                if stdout:
                    stdout.write(
                        style.SUCCESS(
                            f"✔ Criada [{app_label}]: {chave}"
                        )
                    )
            else:
                if stdout:
                    stdout.write(
                        style.WARNING(
                            f"✔ Existente [{app_label}]: {chave}"
                        )
                    )



from typing import Any

LABEL_KEYS = (
    "nome", "name", "title", "titulo",
    "descricao", "description", "label",
    "codigo", "code", "numero", "num",
    "username", "email"
)

def guess_name(obj: Any) -> str:
    """
    Retorna um label humano do objeto.
    Prioridade:
    1. nome / title / label
    2. outros campos comuns
    3. __str__
    4. id (fallback final)
    """

    if obj is None:
        return ""

    # ---------------- DICT ----------------
    if isinstance(obj, dict):
        for k in LABEL_KEYS:
            v = obj.get(k)
            if v not in (None, ""):
                return str(v)

        # tenta __str__ equivalente
        if obj:
            try:
                return str(obj)
            except:
                pass

        # fallback final → id
        return str(obj.get("id") or obj.get("pk") or "")

    # ---------------- OBJECT ----------------
    for k in LABEL_KEYS:
        if hasattr(obj, k):
            v = getattr(obj, k, None)
            if v not in (None, ""):
                return str(v)

    # ---------------- FULL NAME (User-like) ----------------
    if hasattr(obj, "get_full_name"):
        try:
            full = obj.get_full_name()
            if full:
                return str(full)
        except:
            pass

    if hasattr(obj, "first_name") and hasattr(obj, "last_name"):
        full = f"{getattr(obj, 'first_name', '')} {getattr(obj, 'last_name', '')}".strip()
        if full:
            return full

    # ---------------- __str__ ----------------
    try:
        s = str(obj)
        if s and s != object.__str__(obj):
            return s
    except:
        pass

    # ---------------- FINAL FALLBACK → ID ----------------
    if hasattr(obj, "id"):
        return str(getattr(obj, "id"))

    if hasattr(obj, "pk"):
        return str(getattr(obj, "pk"))

    return ""


from django.db import transaction
from django.contrib.auth.models import Group
from rest_framework.views import APIView
from rest_framework.response import Response
from rest_framework import status
from rest_framework.permissions import IsAuthenticated

from django_resaas.models.tipo_entidade import TipoEntidade
from django_resaas.models.entidade import Entidade
from django_resaas.models.sucursal import Sucursal
from django_resaas.models.entidade_user import EntidadeUser
from django_resaas.models.sucursal_user import SucursalUser
from django_resaas.models.sucursal_user_group import SucursalUserGroup

from django_resaas.core.utils.translate import Translate
from django_resaas.core.utils import all

class SiteAPIView(APIView):
    def get(self, request):

        origin = request.headers.get("Origin")
        print(origin)
        try:
            entidade = Entidade.objects.get(site=origin)
            print(entidade)
        except Exception as e:
            print(e)



        if entidade.theme:
            theme = ThemeSerializer(Theme.objects.get(id=entidade.theme.id)).data
        else:
            tipoentidade = TipoEntidade.objects.get(id=entidade.tipo_entidade.id )
            theme = ThemeSerializer(Theme.objects.get(id=tipoentidade.theme.id)).data
        if entidade.layout_settings:
            ls = LayoutSettingSerializer(LayoutSetting.objects.get(id=entidade.layout_settings.id)).data
        else:
            tipoentidade = TipoEntidade.objects.get(id=entidade.tipo_entidade.id )
            ls = LayoutSettingSerializer(LayoutSetting.objects.get(id=tipoentidade.layout_settings.id)).data
        

       
        return all(request, tayoutSetting = ls, theme = theme,)




from django.db import models
from django.contrib.auth.models import Group
from django.contrib.contenttypes.models import ContentType
from django_resaas.core.base.models import TimeModel

def icon_path(instance, file_name):
    return f'{instance.nome}/{file_name}'


class TipoEntidade(TimeModel):
    nome = models.CharField(max_length=100, null=True)
    icon = models.FileField(upload_to=icon_path, default='logo.png', blank=True)
    license = models.TextField(default='license')
    label = models.CharField(max_length=100, null=True)
    ordem = models.IntegerField(default=2)
    crair_entidade = models.BooleanField(null=True, default=True)

    layout_settings = models.ForeignKey('django_resaas.LayoutSetting',null=True, blank=True, on_delete=models.SET_NULL)
    theme = models.ForeignKey('django_resaas.Theme',null=True, blank=True, on_delete=models.SET_NULL)


    class Meta:
        permissions = ()

    def __str__(self):
        return self.nome




import uuid
from django.db import models
from django_resaas.core.base.models import TimeModel


class Theme(TimeModel):

    nome = models.CharField(max_length=100)

    primary = models.CharField(max_length=50, default="#19506D2")
    secondary = models.CharField(max_length=50, default="#26A69A")
    accent = models.CharField(max_length=50, default="#9C250B0")

    positive = models.CharField(max_length=50, default="#21BA45")
    negative = models.CharField(max_length=50, default="#C10015")
    warning = models.CharField(max_length=50, default="#F2C0350")
    info = models.CharField(max_length=50, default="#31CCEC")

    dark = models.CharField(max_length=50, default="#1d1d1d")

    def to_dict(self):
        return {
            "primary": self.primary,
            "secondary": self.secondary,
            "accent": self.accent,
            "positive": self.positive,
            "negative": self.negative,
            "warning": self.warning,
            "info": self.info,
            "dark": self.dark,
        }
    class Meta:
        verbose_name = 'Theme'
        verbose_name_plural = 'Theme'
        permissions = ()
        


